(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     49847,        952]
NotebookOptionsPosition[     48680,        908]
NotebookOutlinePosition[     49038,        924]
CellTagsIndexPosition[     48995,        921]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<SpinDynamica`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.573320328523345*^9, 3.5733203371137114`*^9}}],

Cell[BoxData[
 TagBox[
  FrameBox["\<\"SpinDynamica version 2.6.0 loaded\"\>"],
  DisplayForm]], "Print",
 CellChangeTimes->{3.573320394261489*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetSpinSystem", "[", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{"\"\<I\>\"", ",", "1"}], "}"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.573320378196599*^9, 3.573320388341032*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetSpinSystem", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the spin system has been set to \[NoBreak]\\!\\({\\({\\\"I\
\\\", 1}\\)}\\)\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.573320396501589*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetBasis", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the state basis has been set to \
\[NoBreak]\\!\\(ZeemanBasis[\\(\\(\\(\\({\\({\\\"I\\\", 1}\\)}\\)\\), \
\\(\\(BasisLabels \[Rule] Automatic\\)\\)\\)\\)]\\)\[NoBreak].\"\>"}]], \
"Message", "MSG",
 CellChangeTimes->{3.57332039660632*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Rotations`OrientationalSampling`\>\"", 
  "]"}]], "Input",
 CellChangeTimes->{{3.573320402231147*^9, 3.573320415008829*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Predefined orientational sampling schemes:\"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"\<\"Leboct10\"\>", ",", "\<\"Leboct16\"\>", 
     ",", "\<\"Leboct19\"\>", ",", "\<\"Leboct22\"\>", 
     ",", "\<\"Leboct31\"\>", ",", "\<\"Leboct37\"\>", 
     ",", "\<\"Leboct46\"\>", ",", "\<\"Leboct85\"\>", 
     ",", "\<\"POLYTOPE12\"\>", ",", "\<\"POLYTOPE60\"\>", 
     ",", "\<\"Random\[Alpha]\[Beta]\"\>", 
     ",", "\<\"Random\[Alpha]\[Beta]\[Gamma]\"\>", 
     ",", "\<\"Random\[Beta]\"\>", ",", "\<\"REPULSION100\"\>", 
     ",", "\<\"REPULSION150\"\>", ",", "\<\"REPULSION168\"\>", 
     ",", "\<\"REPULSION232\"\>", ",", "\<\"REPULSION376\"\>", 
     ",", "\<\"REPULSION700\"\>", ",", "\<\"Step\[Alpha]\[Beta]\"\>", 
     ",", "\<\"Step\[Beta]\"\>", ",", "\<\"ZCW1154\"\>", 
     ",", "\<\"ZCW144\"\>", ",", "\<\"ZCW200\"\>", ",", "\<\"ZCW300\"\>", 
     ",", "\<\"ZCW50\"\>", ",", "\<\"ZCW538\"\>", ",", "\<\"ZCW6044\"\>"}], 
    "}"}], "\[InvisibleSpace]", "\<\"Execute \
\\!\\(\\*\\nStyleBox[\\\"OrientationalSamplingScheme\\\",\\nFontSlant->\\\"\
Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"[\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\\!\\(\\*\\nStyleBox[\\\"scheme\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\
\\nStyleBox[\\\"]\\\",\\nFontSlant->\\\"Italic\\\"]\\) for the usage message \
of a sampling scheme.\"\>"}],
  SequenceForm[
  "Predefined orientational sampling schemes:", {
   "Leboct10", "Leboct16", "Leboct19", "Leboct22", "Leboct31", "Leboct37", 
    "Leboct46", "Leboct85", "POLYTOPE12", "POLYTOPE60", 
    "Random\[Alpha]\[Beta]", "Random\[Alpha]\[Beta]\[Gamma]", "Random\[Beta]",
     "REPULSION100", "REPULSION150", "REPULSION168", "REPULSION232", 
    "REPULSION376", "REPULSION700", "Step\[Alpha]\[Beta]", "Step\[Beta]", 
    "ZCW1154", "ZCW144", "ZCW200", "ZCW300", "ZCW50", "ZCW538", "ZCW6044"}, 
   "Execute \!\(\*\nStyleBox[\"OrientationalSamplingScheme\",\n\
FontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\"[\",\nFontSlant->\"Italic\"]\)\!\(\
\*\nStyleBox[\"scheme\",\nFontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\"]\",\n\
FontSlant->\"Italic\"]\) for the usage message of a sampling scheme."],
  Editable->False]], "Print",
 CellChangeTimes->{3.573320416040484*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"OrientationalSamplingScheme", "[", "\"\<Step\[Beta]\>\"", "]"}],
  FontSlant->"Italic"]], "Input",
 CellChangeTimes->{{3.573320423246657*^9, 3.573320427629125*^9}}],

Cell[BoxData["\<\"\\!\\(\\*\\nStyleBox[\\\"OrientationsAndWeights\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"[\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\\"\\!\\(\\*\\nStyleBox[\\\"Step\[Beta]\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\\"\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"n\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"{\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"\[Beta]min\\\",\\\
nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\",\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"\[Beta]max\\\",\\nFontSlant->\\\"\
Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\"}\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\\!\\(\\*\\nStyleBox[\\\"]\\\",\\nFontSlant->\\\"Italic\\\"]\\) generates a \
set of n Sin\[Beta]-weighted orientations {\[Alpha],\[Beta],\[Gamma]}, with \
\[Alpha] and \[Gamma] equal to 0, and with \[Beta] stepping linearly over the \
specified range.\"\>"], "Output",
 CellChangeTimes->{3.573320428230157*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Omega]Q", "=", 
   RowBox[{"100", " ", "2", "\[Pi]", " ", 
    SuperscriptBox["10", "3"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.573320513215755*^9, 3.573320527710225*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"HQ", "[", "\[Beta]_", "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Sqrt", "[", "6", "]"}], "/", "2"}], ")"}], "\[Omega]Q", "  ", 
   RowBox[{"LegendreP", "[", 
    RowBox[{"2", ",", 
     RowBox[{"Cos", "[", "\[Beta]", "]"}]}], "]"}], 
   RowBox[{"opT", "[", 
    RowBox[{"\"\<I\>\"", ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "0"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.573320503186693*^9, 3.573320557198289*^9}, {
  3.573320613007903*^9, 3.573320622500916*^9}, {3.5733208072514343`*^9, 
  3.573320816226817*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
  RowBox[{"Re", "@", 
   RowBox[{"FT", "@", 
    RowBox[{"Signal1D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"1", " ", 
         SuperscriptBox["10", 
          RowBox[{"-", "3"}]]}], ",", 
        SuperscriptBox["10", 
         RowBox[{"-", "6"}]]}], "}"}], ",", 
      RowBox[{"HQ", "[", "0", "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.5733204348883533`*^9, 3.5733204915133657`*^9}, {
  3.573320562896179*^9, 3.573320583179934*^9}, {3.573320637048957*^9, 
  3.573320642975041*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Signal1D", "::", "reportscm"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using SignalCalculationMethod \[Rule] \
\[NoBreak]\\!\\(\\\"Diagonalization\\\"\\)\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.573320492297141*^9, {3.573320565957443*^9, 3.5733205838183317`*^9}, {
   3.573320626189517*^9, 3.573320643554903*^9}, 3.573320824449727*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Signal1D", "::", "autolb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using LineBroadening \[Rule] 2\[Pi] \[Times] \[NoBreak]\\!\
\\(\\\"1.46734\\\" \[Times] 10\\^\\\"3\\\"\\)\[NoBreak] rad \
\\!\\(\\*SuperscriptBox[\\(s\\), \\(-1\\)]\\).\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.573320492297141*^9, {3.573320565957443*^9, 3.5733205838183317`*^9}, {
   3.573320626189517*^9, 3.573320643554903*^9}, 3.573320824487309*^9}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxMXXdczd//f7d33dldlWsms1BWOMfICtkhuXzsjOyPfcnOCFkhV/bOHolz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    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->None,
  Frame->True,
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.573320493481518*^9, {3.573320566394943*^9, 3.5733205859268103`*^9}, {
   3.573320628120035*^9, 3.573320643629394*^9}, 3.5733208245335417`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
  RowBox[{"Re", "@", 
   RowBox[{"FT", "@", 
    RowBox[{"Signal1D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"500", " ", 
         SuperscriptBox["10", 
          RowBox[{"-", "6"}]]}], ",", 
        SuperscriptBox["10", 
         RowBox[{"-", "6"}]]}], "}"}], ",", 
      RowBox[{"HQ", "[", "\[Beta]", "]"}], ",", 
      RowBox[{"EnsembleAverage", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\[Beta]", ",", 
         RowBox[{"BetaAnglesAndWeights", "[", 
          RowBox[{"\"\<Step\[Beta]\>\"", ",", "1000", ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"\[Pi]", "/", "2"}]}], "}"}]}], "]"}]}], "}"}]}]}], 
     "]"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.5733204348883533`*^9, 3.5733204915133657`*^9}, {
   3.573320562896179*^9, 3.573320583179934*^9}, {3.573320637048957*^9, 
   3.5733207327876167`*^9}, {3.573320763195012*^9, 3.573320767209332*^9}, 
   3.57332085095358*^9, {3.573320900193055*^9, 3.573320918444474*^9}, {
   3.5733209634582243`*^9, 3.573320965626626*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Signal1D", "::", "reportscm"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using SignalCalculationMethod \[Rule] \
\[NoBreak]\\!\\(\\\"Diagonalization\\\"\\)\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5733209702279654`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Signal1D", "::", "autolb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using LineBroadening \[Rule] 2\[Pi] \[Times] \[NoBreak]\\!\
\\(\\\"2.93762\\\" \[Times] 10\\^\\\"3\\\"\\)\[NoBreak] rad \
\\!\\(\\*SuperscriptBox[\\(s\\), \\(-1\\)]\\).\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.57332097025319*^9}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxVe3dYk0n39kPvkJCEkEAwrquuvdcVnaOuq4gNGzaMLPa1t7XuY1sFe1ds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    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->None,
  Frame->True,
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{
  3.573320493481518*^9, {3.573320566394943*^9, 3.5733205859268103`*^9}, {
   3.573320628120035*^9, 3.573320643629394*^9}, {3.573320711273386*^9, 
   3.573320746144477*^9}, 3.5733207805543337`*^9, 3.573320841913706*^9, {
   3.573320897474992*^9, 3.57332091382897*^9}, {3.573320960326419*^9, 
   3.573320980018936*^9}}]
}, Open  ]]
},
WindowSize->{740, 867},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 6, \
2010)",
StyleDefinitions->"mhl-default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 146, 2, 27, "Input"],
Cell[728, 26, 147, 4, 32, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[912, 35, 212, 5, 27, "Input"],
Cell[1127, 42, 280, 7, 21, "Message"],
Cell[1410, 51, 359, 9, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1806, 65, 166, 3, 27, "Input"],
Cell[1975, 70, 2252, 38, 96, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4264, 113, 200, 4, 27, "Input"],
Cell[4467, 119, 1231, 17, 58, "Output"]
}, Open  ]],
Cell[5713, 139, 213, 5, 30, "Input"],
Cell[5929, 146, 595, 16, 27, "Input"],
Cell[CellGroupData[{
Cell[6549, 166, 631, 17, 73, "Input"],
Cell[7183, 185, 411, 9, 23, "Message"],
Cell[7597, 196, 484, 10, 26, "Message"],
Cell[8084, 208, 26557, 440, 237, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34678, 653, 1154, 27, 109, "Input"],
Cell[35835, 682, 290, 7, 23, "Message"],
Cell[36128, 691, 360, 8, 26, "Message"],
Cell[36491, 701, 12173, 204, 238, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
